#ifndef MV1_H
#define MV1_H

#include <stdlib.h>
#include <stdio.h>
#include <unistd.h>
#include <sys/types.h>
#include <sys/mman.h>
#include <X11/X.h>
#include <X11/Xlib.h>
#include <sys/ioctl.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <sys/signal.h>
#include <fcntl.h>
#include <string.h>

#include "mv1drv.h"


#define PAGE_SIZE 4096
#define U32 u_long
#define U16 u_short
#define U8 u_char

/* Errorcodes */
#define MV1_OK 0

// These definitions are from the Manual, and contradict the 
// definitions from the Mutech register.h file

#define MV1_CSyncClock		0x0
#define MV1_ExtHSyncClock	0x1
#define MV1_ExtClock		0x2
#define MV1_14MHz		0x3 

// define MV1_Sync_Out_Disable	#0x1401
#define MV1_CSync_Out		0x0
#define MV1_HVSync_Out		0x1

#define ICS_BEST_VCO_FREQ 	(50e6)
#define ICS_MAX_VCO_FREQ	(230e6)
#define ICS_MIN_VCO_FREQ	(14e6)

typedef struct {
	int ctrl_fd;
	int raw_fd;
	int raw_zoom;
	void *video_mem;
	int lut0_locked;
	int private_lut;
        unsigned long *lut10_32;
        unsigned short *lut10_16;

} MV1_Ctrl;
typedef struct {

	u_short PixelPerLine;	/* total number, including borders */
	float hPeriod;
	u_char  PhaseTriming;
	u_char clockReference ; /*  Source ???? */
	u_char LeadLag;
	u_char forceEQRemove;
	float PixelClockFreq;  

} MV1_PLLSyncCtl;

typedef struct {
	/* video selection */
	u_char  videoChannel;
	u_char syncChannel;

	/*	grab windows 	*/
	u_short hOffset;
	u_short vOffset;

	/*  	video conditioning 	*/	
	u_short ClampControl; /* 0 = , 1 = ,2 = */
	u_short ADTop; 
	u_short ADBottom;
	u_short ClampLevel;
	u_short DCOffset;

	/*	filter operation 	*/
	u_char filterCutoff;
	u_char filterBoost;

	/* 	PLL and Sync control	*/
	MV1_PLLSyncCtl pll;

	/* 	camera drive control	*/
	u_char cameraMasterClock :1;
	u_char cameraInterlace :1;
	u_char cameraDriveVPolarity :1;
	u_char cameraDriveHPolarity :1;
	u_char cameraSyncOutput        :1;
    	u_char cameraCSyncOutput       :1;
    	u_char cameraClockDivideBy4    :1;
    	u_char cameraDriveThroughModule:1;
   	u_char cameraHGatePolarity     :1;
        u_char :7;
	u_short cameraDriveWidth;
	u_short cameraDriveHeight; 
	u_short cameraPixelPerLine;
	float cameraClockFrequency;
	u_short cameraLinePerFrame;
	u_short cameraFlag_EquSerr;
	u_short cameraEq_Start;
	u_short cameraEq_End;

	/*	misc	*/
	u_char externalTrigger;
	u_char externalTriggerPolarity;
	u_char flagInterlace;
	u_char Start_Field;
	u_char externalClock;	/* Pixel Clock  */
	u_char Flag_DigitalCamera;	
	u_char Flag_Video_AC_Couple;
	u_char Flag_Sync_DC_Couple;
	u_char Flag_Sync_Termination;
	u_char bitPerPixel;
	u_char bitmode;	
	u_char lineScanCamera;
	u_char External_Sync_Input;
	u_char External_CSync_Input;
	u_char HSync_Polarity;
	/*
		Digital Camera info should be here
        */
	u_short MaxCaptureSizeH; 
        u_short MaxCaptureSizeV;	

} MV1_CamConfig;


typedef struct {    
	u_char PixelMode;	
} MV1_InitConfig;

#define MV1_Memory(ctrl) ( ctrl->video_mem )

/*
 * ------------------------------------------------------
 *
 *	Write directly to registers.
 *	normally You should use the lib-calls.
 *
 * ------------------------------------------------------
 */

// *****************************************************

static inline int
MV1_SetHStart(u_long hstart,MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_SET_H_START,hstart);
}

static inline int 
MV1_InquireHStart(MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_H_START);
}
static inline int 
MV1_SetHEnd(u_long hend,MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_SET_H_END,hend);
}
static inline int 
MV1_InquireHEnd(MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_H_END);
}
static inline int
MV1_SetVStart(u_long vstart,MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_SET_V_START,vstart);
}
static inline int
MV1_InquireVStart(MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_V_START);
}
static inline int
MV1_SetVEnd(u_long vend,MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_SET_V_END,vend);
}
static inline int
MV1_InquireVEnd(MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_V_END);
}
static inline int
MV1_InquireCurLine(MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_CUR_LINE);
}
static inline int
MV1_SetEqRemove(u_long eq,MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_SET_EQ_REMOVE,eq);
}
static inline int
MV1_InquireEqRemove(MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_EQ_REMOVE);
}

/* +++++++++++++++++++++++++++++++++				*/
extern int MV1_Is10Bit(MV1_Ctrl *ctrl);

#define MV1_8bit_Mode           0x0
#define MV1_10bit_Mode          0x1
// ?? define MV1_12bit_Mode     0x1003
#define MV1_16bit_Mode          0x3
#define MV1_32bit_Mode          0x4
//#define MV1_YUV16bit_Mode     0x1006

static inline int 
MV1_SelectPixelMode(u_long pm,MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV1_SELECT_PIXELMODE,pm);
}
static inline int
MV1_InquirePixelMode(MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_PIXELMODE);
}
static inline int
MV1_InquirePixelBits(MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd, MV1_INQUIRE_PIXELBITS);
}

static inline int
MV1_SelectTransferMode(u_long tm,MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV1_SELECT_TRANSFER_MODE,tm);
}
int  MV1_LoadCameraConfigFile(MV1_CamConfig *, char *filename); 
int MV1_SetPLLControl(MV1_PLLSyncCtl *,MV1_Ctrl *ctrl);
int MV1_GetPLLControl(MV1_PLLSyncCtl *,MV1_Ctrl *ctrl);

/* 
 * Selects a video source for composite video input.
 * default is 3
 * 0 red cable
 * 1 green  cable
 * 2 blue cable
 * 3 gray cable
 */
static inline int	
MV1_SetCVideoSource(u_long source, MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_SET_CVIDEO_SOURCE,source);
}

static inline int
MV1_InquireCVideoSource(MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_CVIDEO_SOURCE);
}

static inline int
MV1_SetCSyncSource(u_long source,MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV1_SET_CSYNC_SOURCE,source);
}
static inline int
MV1_InquireCSyncSource(MV1_Ctrl *ctrl) {
        return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_CSYNC_SOURCE);
}


static inline int
MV1_SelectClockSource(u_long source,MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd, MV1_SELECT_CLOCK_SOURCE,source);
}

static inline int
MV1_InquireClockSource(MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_CLOCK_SOURCE);
}

/*
 * MV1SelectSyncStripRange 
 *
 * Selects a sync stripper range
 * 0 = 5-10 kHz
 * 1 = 10-20 kHz
 * 2 = 20-40 kHz
 * 3 = 40-64 kHz
 *
 */
static inline int
MV1_SelectSyncStripRange(u_long range,MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_SELECT_SYNC_STRIP_RANGE,range);
}
static inline int 
MV1_InquireSyncStripRange(MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_SYNC_STRIP_RANGE);
}
static inline int
MV1_SelectADConvertor(u_long adc,MV1_Ctrl *ctrl){
	return ioctl (ctrl->ctrl_fd,MV1_SET_SHIFT_DOWN,adc);
}
static inline int
MV1_InquireADConvertor(MV1_Ctrl *ctrl){
	return ioctl (ctrl->ctrl_fd,MV1_INQUIRE_SHIFT_DOWN);
}

static inline int
MV1_SetPLLPhaseTrim(u_long trim,MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV1_SET_PLL_PHASE_TRIM,trim);
}
static inline int
MV1_InquirePLLPhaseTrim(MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_PLL_PHASE_TRIM);
}
static inline int
LM1882_SelectSyncOutput(u_long output,MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,LM1882_SELECT_SYNC_OUTPUT,output);
}
static inline int
LM1882_InquireSyncOutput(MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,LM1882_INQUIRE_SYNC_OUTPUT);
}
static inline int
LM1882_SelectEQSerr(u_long eqserr,MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,LM1882_SELECT_EQSERR,eqserr);
}
static inline int
LM1882_InquireEQSerr(MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,LM1882_INQUIRE_EQSERR);
}

static inline int
LM1882_SelectVCSyncPolarity(u_long pol,MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,LM1882_SELECT_VCSYNC_POLARITY,pol);
}
static inline int
LM1882_InquireVCSyncPolarity(MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,LM1882_INQUIRE_VCSYNC_POLARITY);
}
static inline int
LM1882_SelectHSyncPolarity(u_long pol,MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,LM1882_SELECT_HSYNC_POLARITY,pol);
}
static inline int
LM1882_InquireHSyncPolarity(MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,LM1882_INQUIRE_HSYNC_POLARITY);
}
static inline int
LM1882_SetPixelPerLine(u_long pixel,MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,LM1882_SET_PIXEL_PER_LINE,pixel);
}
static inline int
LM1882_InquirePixelPerLine(MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,LM1882_INQUIRE_PIXEL_PER_LINE);
}
static inline int
LM1882_SetLinePerFrame(u_long line,MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,LM1882_SET_LINE_PER_FRAME,line);
}
static inline int
LM1882_InquireLinePerFrame(MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,LM1882_INQUIRE_LINE_PER_FRAME);
}
/*
 *
 *	Digital Module MV1100
 */
static inline int
MV11_SetPulseMode(u_long mode,MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV11_SET_PULSE_MODE,mode);
}
static inline int
MV11_InquirePulseMode(MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV11_INQUIRE_PULSE_MODE);
}

static inline int
MV11_SetModeControl(u_long mc,MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV11_SET_MODE_CONTROL,mc);
}

static inline int
MV11_InquireModeControl(MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV11_INQUIRE_MODE_CONTROL);
}

static inline int
MV11_SelectParFrameRem(u_long par,MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV11_SELECT_PAR_FRAME_REMOVE,par);
}

static inline int
MV11_InquireParFrameRem(MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV11_INQUIRE_PAR_FRAME_REMOVE);
}

static inline int
MV11_SelectClock(u_long clock,MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV11_SELECT_CLOCK,clock);
}

static inline int
MV11_InquireClock(MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV11_INQUIRE_CLOCK);
}

static inline int
MV11_SetBypassCounter(u_long byp,MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV11_SET_BYPASS_COUNTER,byp);
}

static inline int
MV11_InquireBypassCounter(MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV11_INQUIRE_BYPASS_COUNTER);
}

static inline int
MV11_SelectCameraDrive(u_long drive,MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV11_SELECT_CAMERA_DRIVE,drive);
}

static inline int
MV11_InquireCameraDrive(MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV11_INQUIRE_CAMERA_DRIVE);
}

static inline int
MV11_SetCounter(u_long  counter,MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV11_SET_COUNTER,counter);
}

static inline int
MV11_InquireCounter(MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV11_INQUIRE_COUNTER);
}

static inline int
MV11_SetTrigEnable(u_long trig ,MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV11_SET_TRIG_ENABLE,trig);
}

static inline int
MV11_InquireTrigEnable(MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV11_INQUIRE_TRIG_ENABLE);
}

static inline int
MV11_SetTrigPol(u_long pol,MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV11_SET_TRIG_POL,pol);
}

static inline int
MV11_InquireTrigPol(MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV11_INQUIRE_TRIG_POL);
}

static inline int
MV11_SetLsExp(u_long ls_exp,MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV11_SET_LS_EXP,ls_exp);
}

static inline int
MV11_InquireLsExp(MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV11_INQUIRE_LS_EXP);
}

static inline int
MV11_SetLDVPol(u_long pol,MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV11_SET_LDV_POL,pol);
}

static inline int
MV11_InquireLDVPol(MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV11_INQUIRE_LDV_POL);
}

static inline int
MV11_SetFDVPol(u_long pol,MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV11_SET_FDV_POL,pol);
}

static inline int
MV11_InquireFDVPol(MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV11_INQUIRE_FDV_POL);
}

static inline int
MV11_SetPCLKPol(u_long pol,MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV11_SET_PCLK_POL,pol);
}

static inline int
MV11_InquirePCLKPol(MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV11_INQUIRE_PCLK_POL);
}
static inline int
MV1_SetTopShiftControl(u_long sc,MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV1_SET_TOP_SC,sc);
}
static inline int
MV1_InquireTopShiftControl(MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_TOP_SC);
}


static inline int
MV1_RdVSyncInfo(MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV1_RD_VSYNC_INFO);
}

extern int MV1_SetDigitizeLevel(int top_ref, int bottom_ref,MV1_Ctrl *bd);

static inline int
MV1_SetADTopLevel(u_long level,MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_SET_AD_TOP_LEVEL,level);
}
static inline int
MV1_InquireADTopLevel(MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_AD_TOP_LEVEL);
}
static inline int
MV1_SetADBottomLevel(u_long level,MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_SET_AD_BOTTOM_LEVEL,level);
}
static inline int
MV1_InquireADBottomLevel(MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_AD_BOTTOM_LEVEL);
}
/*	
case MV1_INQUIRE_FIELD:
case MV1_IS_FRAME_END:
	return -EINVAL;
*/
static inline int
MV1_SetClampLevel(u_long level,MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV1_SET_CLAMP_LEVEL,level);
}
static inline int
MV1_InquireClampLevel(MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_CLAMP_LEVEL);
}

/*    
 * MV1SelectClamping
 *      Selects the clamping reference
 */
#define MV1_No_Clamp            #0x0
#define MV1_BackPorch_Clamp     #0x1
#define MV1_SyncTip_Clamp       #0x2

static inline int
MV1_SelectClamping(u_long clamp,MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd, MV1_SELECT_CLAMPING,clamp);
}
static inline int
MV1_InquireClamping(MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_CLAMPING);
}
/*	
case MV1_SET_DIG_CAMERA_CONFIG:
case MV1_SETCOLOR_MODULE_CONFIG:
	return -EINVAL;
*/
static inline int
MV1_SetPllPhaseDetector(u_long det,MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_SET_PLL_PHASE_DETECTOR,det);
}
/*
case MV1_SET_LSEXP_REDUCTION:
*/
static inline int
MV1_SetDCOffset(u_long offset,MV1_Ctrl *ctrl){
        return ioctl(ctrl->ctrl_fd, MV1_SET_DC_OFFSET,offset);
}

static inline int
MV1_InquireDCOffset(MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_DC_OFFSET);
}

#define MV1_XTrig_Disable       0x0
#define MV1_XTrig_Enable        0x1
#define MV1_XTrig_Low           0x0
#define MV1_XTrig_High          0x1

static inline int
MV1_SetExtTrigger(u_long t_flag,MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_SET_EXT_TRIGGER,t_flag);
}
static inline int
MV1_InquireExtTrigger(MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_EXT_TRIGGER);
}
static inline int
MV1_SetTriggerPolarity(u_long pol,MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_SET_TRIGGER_POLARITY,pol);
}
static inline int
MV1_InquireTriggerPolarity(MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_TRIGGER_POLARITY);
}
static inline int
MV1_SetInterlace(u_long interlace,MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV1_SET_INTERLACE,interlace);
}
static inline int
MV1_InquireInterlace(MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_INTERLACE);
}
extern int MV1_SetExtTriggerMode(int t_flag,int t_pol,MV1_Ctrl *);

// returns 1 on success, 0 if not external triggered or -EINTR if interrupted

static inline int
MV1_WaitExtTrigger(int poll, MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_WAIT_EXT_TRIGGER,poll);
}
extern int MV1_CreateGrabWindow(u_long offset, u_long sx,u_long sy,
        u_long dx,u_long dy, MV1_GrabWindow *gW,MV1_Ctrl *bd);
extern int MV1_SetGrabWindow(MV1_GrabWindow *gw,MV1_Ctrl *bd);
extern int MV1_InquireGrabWindowSize(u_long *dx,u_long *dy,MV1_Ctrl *ctrl);
extern int MV1_CreateMaxFrame(MV1_Frame *frame,MV1_GrabWindow *gw);

int 
MV1InquireMaxGrabWindowSize(u_long *dx,u_long *dy);

int 
MV1_CreateFrame(MV1_Frame *frame,u_long sx,u_long sy,u_long dx, u_long dy,
	MV1_GrabWindow *gW,MV1_Ctrl *bd);

/*
case MV1_SET_EXT_TRIGGER_MODE:
case MV1_WAIT_EXT_TRIGGER:
case MV1_SET_DIG_CAMERA_CONTROL:
case MV1_SET_COLOR_MODULE_CONTROL:
case MV1_SET_GRAB_WINDOW:	
case MV1_INQUIRE_GRAB_WINDOW_SIZE:
case MV1_INQUIRE_MAX_GRAB_WINDOW_SIZE:
cdee MV1_CREATE_FRAME			
case MV1_FRAME_FILL:
case MV1_FRAME_LINE_READ:
case MV1_FRAME_LINE_WRITE:
case MV1_FRAME_READ:
case MV1_FRAME_READ_FIELD:
case MV1_FRAME_WRITE:
	return -EINVAL;
*/

static inline int
MV1_WaitFrameEnd(MV1_Ctrl *ctrl){ 
	return ioctl(ctrl->ctrl_fd,MV1_WAIT_FRAME_END);
}
static inline int
MV1_WaitTransferEnd(MV1_Ctrl *ctrl){ 
	return ioctl(ctrl->ctrl_fd,MV1_WAIT_TRANSFER_END);
}

static inline int
MV1_SetHostMask(u_long mask,MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_SET_HOST_MASK,mask);
}
static inline int
MV1_InquireHostMask(MV1_Ctrl *ctrl) {	
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_HOST_MASK);
}
static inline int
MV1_SetGrabMask(u_long mask,MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV1_SET_GRAB_MASK,mask);
}
static inline int
MV1_InquireGrabMask( MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_GRAB_MASK);
}
static inline int
MV1_SetFilterCutoff(u_long cutoff, MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV1_SET_FILTER_CUTOFF,cutoff);
}
static inline int
MV1_InquireFilterCutoff(MV1_Ctrl*ctrl) {
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_FILTER_CUTOFF);
}
static inline int
MV1_SetHighFreqBoost(u_long boost, MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_SET_HIGH_FREQ_BOOST,boost);
}
static inline int
MV1_InquireHighFreqBoost(MV1_Ctrl*ctrl) {
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_HIGH_FREQ_BOOST);
}
/*
 * --------------------------------------------------------------
 *
 * Set/Reset General Purpose output pins.
 * BOTH have to be enabled with jumpers before use
 *
 * --------------------------------------------------------------
 */
static inline int
MV1_SetGPBit0(u_long val,MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV1_SET_GP_BIT0,val);
}
static inline int
MV1_InquireGPBit0(MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_GP_BIT0);
}
static inline int
MV1_SetGPBit1(u_long val,MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV1_SET_GP_BIT1,val);
}
static inline int
MV1_InquireGPBit1(MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_GP_BIT1);
}
/*
case MV1_SET_GENERAL_PURPOSE_BIT:
case MV1_RESET_GENERAL_PURPOSE_BIT:
case MV1_SET_LUT_MODE:
*/
static inline int 
MV1_SelectLutBank(u_long bank,MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV1_SELECT_LUT_BANK,bank);
}
static inline int
MV1_InquireLutBank(MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_LUT_BANK);
}

extern int    
MV1_LutWriteValue(u_long value,u_long addr,u_long lut,MV1_Ctrl *ctrl);

extern int MV1_LoadLutDefault(int flag,MV1_Ctrl *ctrl);

static inline int
MV1_SetFrameEndIrq(u_long flag,MV1_Ctrl *bd){
	return ioctl(bd->ctrl_fd,MV1_SET_FRAME_END_IRQ,flag);
}
static inline int
MV1_InquireFrameEndIrq(MV1_Ctrl *bd){
	return ioctl(bd->ctrl_fd,MV1_INQUIRE_FRAME_END_IRQ);
}
// Should this be allowed from User space ?
static inline int
MV1_SetTransferEndIrq(u_long flag, MV1_Ctrl *bd){
	return ioctl(bd->ctrl_fd,MV1_SET_TRANSFER_END_IRQ,flag);
}
static inline int
MV1_InquireTransferEndIrq(MV1_Ctrl *bd){
	return ioctl(bd->ctrl_fd,MV1_INQUIRE_TRANSFER_END_IRQ);
}
static inline int
MV1_InquireFrameEndCount(MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_FRAME_END_COUNT);
}
static inline int
MV1_InquireTransferEndCount(MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_TRANSFER_END_COUNT);
}
static inline int
MV1_InquireBadListCount(MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_BAD_LIST_COUNT);
}
static inline int
MV1_SetGrabFlag(u_long gflag,MV1_Ctrl *bd) {
	return ioctl(bd->ctrl_fd,MV1_SET_GRABFLAG,gflag);
}
static inline int
MV1_InquireGrabFlag(MV1_Ctrl *bd) {
	return ioctl(bd->ctrl_fd,MV1_INQUIRE_GRABFLAG);
}
static inline int
MV1_SetStartField(u_long ifield,MV1_Ctrl *bd) {
	return ioctl(bd->ctrl_fd,MV1_SET_STARTFIELD,ifield);
}
static inline int
MV1_InquireStartField(MV1_Ctrl *bd){
	return ioctl(bd->ctrl_fd,MV1_INQUIRE_STARTFIELD);
}
static inline int    
MV1_SetGrab(u_long value,MV1_Ctrl *bd) {
	return ioctl(bd->ctrl_fd,MV1_SET_GRAB,value);
}


static inline int
MV1_InquireGrab(MV1_Ctrl *bd) {
	return ioctl(bd->ctrl_fd,MV1_INQUIRE_GRAB);
}

// ?????????????????
//extern int
//MV1_LutWrite(u_long start, u_long len,u_long *source,MV1_Ctrl *ctrl){
//return 0;
//}

/*
case MV1_LOAD_LUT_DEFAULT_10_BIT:
case MV1_LOAD_LUT_DEFAULT_10_TO_8_BIT:
case MV1_LOAD_LUT_PASS_THROUGH:
case MV1_START_GRAB:
case MV1_STOP_GRAB:
case MV1_READ_FIELD_LINE_COUNTER:
case MV1_SET_SCALE_FACTOR:
case MV1_SET_VSCALE_FACTOR:
case MV1_SET_HSCALE_FACTOR:
case MV1_GRAB_FIELD:
case MV1_START_GRAB_FIELD:
case MV1_BMP_SAVE:				
case MV1_BMP_LOAD:				
case MV1_GRAPH_MODE:	
case MV1_TEXT_MODE:

 4.10 Master Mode Transfer and Interrupt Handling 

case    MV1_SET_MASTER_CTLID:			
case    MV1_SET_MASTER_MODE_TRANSFER:
case    MV1_SET_MASTER_MODE_TRANSFER_FIELD:
*/
static inline int
MV1_SetMasterEnable(u_long enable,MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_SET_MASTER_ENABLE,enable);	
}
static inline int
MV1_InquireMasterEnable(MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_MASTER_ENABLE);	
}
static inline int
MV1_SetMasterLoop(u_long enable,MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_SET_MASTER_LOOP,enable);	
}
static inline int
MV1_InquireMasterLoop(MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_MASTER_LOOP);	
}
static inline int
MV1_SetMasterWaitFrame(u_long wait,MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV1_SET_MASTER_WAIT_FRAME,wait);	
}
static inline int
MV1_InquireMasterWaitFrame(MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_MASTER_WAIT_FRAME);	
}

/*	ICS-1522 PLL 	*/
static inline int
ICS_SetFbkDiv(u_long div,MV1_Ctrl *ctrl){
	return ioctl(ctrl->ctrl_fd,ICS_SET_FBK_DIV,div);
}
static inline int
ICS_InquireFbkDiv(MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,ICS_INQUIRE_FBK_DIV);
}
static inline int
ICS_SetRefDiv(u_long div,MV1_Ctrl *ctrl){
        return ioctl(ctrl->ctrl_fd,ICS_SET_REF_DIV,div);
}
static inline int
ICS_InquireRefDiv(MV1_Ctrl *ctrl) {
        return ioctl(ctrl->ctrl_fd,ICS_INQUIRE_REF_DIV);
}
static inline int
ICS_SetRefPol(u_long pol,MV1_Ctrl *ctrl){
        return ioctl(ctrl->ctrl_fd,ICS_SET_REF_POL,pol);
}
static inline int
ICS_InquireRefPol(MV1_Ctrl *ctrl) {
        return ioctl(ctrl->ctrl_fd,ICS_INQUIRE_REF_POL);
}
static inline int
ICS_SetVCOGain(u_long gain,MV1_Ctrl *ctrl){
        return ioctl(ctrl->ctrl_fd,ICS_SET_VCO_GAIN,gain);
}
static inline int
ICS_InquireVCOGain(MV1_Ctrl *ctrl) {
        return ioctl(ctrl->ctrl_fd,ICS_INQUIRE_VCO_GAIN);
}
static inline int
ICS_SetPFDGain(u_long gain,MV1_Ctrl *ctrl){
        return ioctl(ctrl->ctrl_fd,ICS_SET_PFD_GAIN,gain);
}
static inline int
ICS_InquirePFDGain(MV1_Ctrl *ctrl) {
        return ioctl(ctrl->ctrl_fd,ICS_INQUIRE_PFD_GAIN);
}
static inline int
ICS_SetPden(u_long flag,MV1_Ctrl *ctrl){
        return ioctl(ctrl->ctrl_fd,ICS_SET_PDEN,flag);
}
static inline int
ICS_InquirePden(MV1_Ctrl *ctrl) {
        return ioctl(ctrl->ctrl_fd,ICS_INQUIRE_PDEN);;
}
static inline int
ICS_SetClkSel(u_long flag,MV1_Ctrl *ctrl){
        return ioctl(ctrl->ctrl_fd,ICS_SET_CLKSEL,flag);
}
static inline int
ICS_InquireClkSel(MV1_Ctrl *ctrl) {
        return ioctl(ctrl->ctrl_fd,ICS_INQUIRE_CLKSEL);
}

static inline int // PDA is output Postscaler
ICS_SetPDA(u_long outps,MV1_Ctrl *ctrl){
        return ioctl(ctrl->ctrl_fd,ICS_SET_PDA,outps);
}
static inline int
ICS_InquirePDA(MV1_Ctrl *ctrl) {
        return ioctl(ctrl->ctrl_fd,ICS_INQUIRE_PDA);
}
static inline int
ICS_SetPDB(u_long pdb,MV1_Ctrl *ctrl){
        return ioctl(ctrl->ctrl_fd,ICS_SET_PDB,pdb);
}
static inline int
ICS_InquirePDB(MV1_Ctrl *ctrl) {
        return ioctl(ctrl->ctrl_fd,ICS_INQUIRE_PDB);
}
/* 
 * Fine Phase Adjust:
 * 1= FBK  will lag REF at input to PFD 
 * 0= FBK will lead REF at input to PFD
 *
 */
static inline int
ICS_SetLeadLag(u_long ldlg,MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,ICS_SET_LEAD_LAG,ldlg);
}
static inline int
ICS_InquireLeadLag(MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,ICS_INQUIRE_LEAD_LAG);
}
static inline int
MV1_GetPrivateLut(MV1_Ctrl *ctrl){
	return (ctrl->private_lut=ioctl(ctrl->raw_fd,MV1_GET_PRIVATE_LUT));
}
static inline int
MV1_FreeLut(MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV1_FREE_LUT);
}
static inline int
MV1_SetIntegrationTime(u_long time,MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV1_SET_INTEGRATION_TIME,time);
}
static inline int
MV1_ResetIntegrationTime(MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV1_RESET_INTEGRATION_TIME);
}
static inline int
MV1_InquireIntegrationTime(MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_INTEGRATION_TIME); 
}
static inline int
MV1_InquireGrabAdrOffsets(u_long *first,u_long *second,MV1_Ctrl *ctrl) {
        int i;
        u_long arg[2];
        i = ioctl(ctrl->ctrl_fd,MV1_INQUIRE_GRAB_ADR_OFFSETS,arg);
        *first = arg[0]; *second = arg[1];
        return i;
}
static inline int
CAM_InquireIntCtlMode(MV1_Ctrl *ctrl) {
        return ioctl(ctrl->ctrl_fd,CAM_INQUIRE_INT_CTL_MODE); 
}
static inline int
CAM_SetIntCtlMode(u_long mode,MV1_Ctrl *ctrl) {
        return ioctl(ctrl->ctrl_fd,CAM_SET_INT_CTL_MODE,mode);
}


/* 
 * -------------------------------------------------------------------------
 *
 * 	begin of higher level lib
 *
 * -------------------------------------------------------------------------
 */
#define MV1_TRANSFER_END_MASK	(1<<25)
#define MV1_FRAME_END_MASK	(1<<28)
#define MV1_BAD_LIST_MASK	(1<<24)
int MV1_ConnectInterruptToCallback(int irqmask,void (*action)(int),MV1_Ctrl *ctrl);

void 
*MV1_MasterMalloc(u_long size,MV1_Ctrl *ctrl);

static inline void
MV1_SetTransferLength(transf_dscr *td,int len) {
	td->len = (((len&~3)^0xfff)+1)<<14;
}
static inline void 
MV1_ClearTransferList(MV1_TransferList *tl) {
	memset(tl,0,sizeof(*tl));
}
int
MV1_AddToTransferList(U32 src,u_long dst,int len,
			MV1_TransferList *tl,MV1_Ctrl *bd);

int
MV1_WriteTransferList(int nr,MV1_TransferList *tl,MV1_Ctrl *ctrl); 

MV1_Ctrl*  MV1_Open(int board);
void  MV1_Close(MV1_Ctrl *);

/* 
 * MV1Init --
 *   	Sets Standard Camera Config if camcfg==NULL
 *	or camcfg.
 *	Selects pixel mode
 *	Selects transfer mode
 *      Loads first bank of LUT to linear indice
 *      Sets all grab masks to 1
 */


/*	
 *
 * MV1SelectTransferMode
 *	Selects Master or Slave Mode
 *
 */
#define MV1_Slave_Mode		0x0
#define MV1_Master_Mode		0x1
int 
MV1SelectTransferMode(u_short tmode);


/* 4.2 Camera Control Setup */

/*
 *
 * MV1SelectSTDCameraConfig 
 *	Selects one of the Standard camera configurations
 *	This does not include the default setting for
 *	sync Gen to generate external Sync
 *
 */ 
#define MV1_RS170_Cam 	0x1101
#define MV1_CCIR_Cam	0x1102
int 
MV1_SelectSTDCameraConfig(MV1_CamConfig *,u_short cflag);

extern int MV1_SetCameraConfig(MV1_CamConfig *camConfig,MV1_Ctrl *);

/*
 * MV1LoadCameraConfigFile
 *	Reads in a Camera configuration file
 *	cfname: A pointer to a file
 *	csname: Pointer to a character string specifiing the
 *	configuration section name ( Use CamConfig for this parameter)
 *
 */
int  
MV1LoadCameraConfigFile(char *cfname, char *csname);
 
/* 
 *
 * MV1InquireCameraConfig
 *	Returns parameters for the currently selected mv1000 board
 *
 */
int 
MV1InquireCameraConfig(MV1_CamConfig *camConfig);


/*
 * MV1SelectADConvertor
 *	Selects 8/10 Bit Conversion
 */
#define MV1_8bit_AD		0x1301
#define MV1_10bit_AD		0x1302
int 
MV1SelectADConvertor(u_short option);




/*
 *	Returns at the end of the frame
 */
int 
MV1WaitFrameEnd(void);

/*
 *   MV1InquireField
 *	returns 0 if current video signal is at even field
 *	returns 1 if current video signal is at odd field
 */
int 
MV1InquireField(void);

/*
 * 
 */
int 
MV1IsFrameEnd(void);

static inline int
MV1_Snap(MV1_Ctrl *ctrl,int flag) {
	return ioctl(ctrl->ctrl_fd,MV1_SNAP,flag);
}

/* 
 * Adjust the Linescan Timing Generation
 */
int 
MV11SetLSExpReduction(u_long Start,u_long End);

/*
 *  MV1GetGain	
 *	returns a floating point value with the
 *	current gain
 */
int 
MV1GetGain(void);

/*
 * MV1SetGain  (0.5 .. 2.0)  (8 Bit)
 */
int
MV1SetGain(float value);

/*
 *  
 */
int 
MV1GetGainRange(float *low,float *high);

int 
MV1GetOffset(void);

int 
MV1SetOffset(float value);

int 
MV1GetOffsetRange(float *low, float *high);

/* 4.3 External Control */ 


int 
MV1WaitExtTrigger(void);

#define MV1_Dig_Counter		0x1700
#define MV1_Dig_Clock_Select	0x1701
#define MV1_Dig_Trig_Polarity	0x1702
#define MV1_Dig_Trig_Enable	0x1703
#define MV1_Dig_Soft_Trig	0x1704
#define MV1_Dig_Mode_Control	0x1705
#define MV1_Dig_Timing_Polarity 0x1706
#define MV1_Dig_Timing_Source   0x1707
#define MV1_Dig_Pulse_Mode	0x1708
#define MV1_Dig_Select_INTEG	0x1709
#define MV1_Dig_Select_MC1	0x170a
#define MV1_Dig_Bypass_Counter  0x170b

int 
MV1SetDigCameraControl(u_short func, u_char data);
#define MV1_RGB_Clamp 		0x1800
#define MV1_RGB_Channel		0x1801
#define MV1_RGB_Ext_CSync	0x1802
#define MV1_RGB_HSync_Polarity	0x1803
#define MV1_RGB_Vsync_Polarity  0x1804
#define MV1_RGB_Sync_On_Green	0x1805
#define MV1_RGB_ADTop_R		0x1806
#define MV1_RGB_ADBottom_R	0x1807
#define MV1_RGB_ADTop_G		0x1808
#define MV1_RGB_ADBottom_G	0x1809
#define MV1_RGB_ADTop_B		0x180a
#define MV1_RGB_ADBottom_B	0x180b
#define MV1_CS_Channel		0x180c
#define MV1_CS_AGC_Off		0x180d
#define MV1_CS_Gain		0x180e
#define MV1_Flag_Pal		0x180f
#define MV1_CS_VCR_Mode		0x1810

/*
int 
MV1SetColorModuleControl(u_short func, u_char data);
*/


int 
MV1WaitGrabDone(void);

/* 4.4 Frame Coordinates and Frame Access */
int 
MV1WaitGrabDone(void);

extern int
MV1_CreateGrabWindow(u_long offset, u_long sx,u_long sy,
        u_long dx,u_long dy, MV1_GrabWindow *gw,MV1_Ctrl *);

extern int 
MV1_SetGrabWindow(MV1_GrabWindow *gw,MV1_Ctrl *);

static inline int 
MV1_InquireGrabWindow(MV1_GrabWindow *gw,MV1_Ctrl *bd){
         return ioctl(bd->raw_fd,MV1_INQUIRE_GRAB_WINDOW,gw);
}

static inline int 
MV1_SetFrame(MV1_Frame *frame, MV1_Ctrl *bd){
        return ioctl(bd->raw_fd,MV1_SET_FRAME,frame);
}
static inline int
MV1_InquireFrame(MV1_Frame *frame, MV1_Ctrl *bd){
        return ioctl(bd->raw_fd,MV1_INQUIRE_FRAME,frame);
}

extern int MV1_InquireGrabWindowSize(u_long *dx,u_long *dy,MV1_Ctrl *);

extern int MV1_InquireMaxGrabWindowSize(u_long *dx,u_long dy);


int 
MV1_FrameFill(MV1_Frame *frame, u_long sx,u_long sy,u_long dx,u_long dy,u_short val);


int 
MV1_FrameLineRead(MV1_Frame *frame, u_long sx,u_long sy,u_long dx, void *dest);

int 
MV1_FrameLineWrite(MV1_Frame *frame,u_long sx,u_long sy,u_long dx,void *dest);

static inline int 
MV1_FrameRead(MV1_Frame *frame, void *dest,MV1_Ctrl *bd){
	lseek(bd->raw_fd,0,SEEK_SET);
	return read(bd->raw_fd,dest,frame->dx*frame->dy>>(bd->raw_zoom<<1));
}


int 
MV1_FrameReadField(MV1_Frame *frame, u_short ifield, void *buffer);

int 
MV1_FrameWrite(MV1_Frame *frame, u_long sx,u_long sy, u_long dx,u_long dy,void *dest);


/* 4.5 Individual Feature Control */ 
#define MV1_Mem_Mask	0x1489
#define MV1_Grab_Mask	0x147d 
int 
MV1SetMask(u_short m_flag, u_short mask);

int 
MV1EnableMask(u_short m_flag); 

int
MV1DisableMask(u_short m_flag);

#define MV1_GP_Bit0  0x1900
#define MV1_GP_Bit1  0x1901
int
MV1SetGeneralPurposeBit(u_char reg);

int 
MV1ResetGeneralPurposeBit(u_char reg);

/* 4.6 Look Up Table Operations */
int 
MV1SetLUTMode(u_short imode);

int 
MV1LUTRead(u_short StartIndex, u_short lenght, u_long *dest);

/* 4.6 Look Up Table Operations */
int MV1_WriteSoftLut8_32(unsigned long *lut,MV1_Ctrl *bd);
int MV1_Write8BitLut(u_long *table,int lut,MV1_Ctrl *bd); 
int MV1_LutWrite(u_short startbin, u_short len, u_long *source,MV1_Ctrl *bd);

  
int 
MV1LoadLUTDefault10Bit(u_short order);

int
MV1LoadLUTDefault10to8Bit(u_short order);

int 
MV1LoadLUTPassThrough(void);

/* 4.7 Grab Image	*/

int MV1_XImageRead(MV1_Frame *frame, XImage *xim,MV1_Ctrl *bd);

#define MV1_SingleGrab  MV1_SINGLE_GRAB
#define MV1_ContGrab	MV1_CONT_GRAB
#define MV1_GrabEven	MV1_GRAB_EVEN
#define MV1_GrabOdd   	MV1_GRAB_ODD
#define MV1_GrabNext	MV1_GRAB_NEXT


int 
MV1StopGrab(void);

int
MV1ReadFieldLineCounter(void);

int
MV1SetScaleFactor(u_short scale);

int
MV1SetVScaleFactor(u_short scale);

int
MV1SetHScaleFactor(u_short scale);

int
MV1GrabField(MV1_Frame *frame, u_short ifield, void *buffer);

int 
MV1StartGrabField(MV1_Frame *frame, u_short ifield, void *buffer);


/* 4.8 Image File Acess */


/* 4.9 VESA VGA */


/* 4.10 Master Mode Transfer and Interrupt Handling */


static inline int MV1_InquireRestTime(MV1_Ctrl *ctrl) {
	return ioctl(ctrl->ctrl_fd,FG_INQUIRE_REST_TIME);
}
static inline int MV1_InquireTimeSinceLastInt(MV1_Ctrl *ctrl) {
        return ioctl(ctrl->ctrl_fd,MV1_INQUIRE_MACHINE_STATE);
}
static inline int MV1_SetZoom(MV1_Ctrl *ctrl,int zoom) {
	ctrl->raw_zoom = zoom&1;
	return ioctl(ctrl->raw_fd,MV1_SET_ZOOM,zoom);
}
u_long
MV1_GetBusAddress(u_long mem,MV1_Ctrl *ctrl);

inline void
MV1_ValidateSDC(transf_dscr *td);

static inline int
MV1_GetEvent(MV1_Event *event,MV1_Ctrl *bd) {
	return read(bd->ctrl_fd,event,sizeof(MV1_Event));
}

#endif
